---
sidebar_position: 1
---

# チュートリアル導入

**Docusaurus**について5分以内で学んでいきましょう。

## はじめに

**新しいサイトを作成**することから始めましょう。

または**[docusaurus.new](https://docusaurus.new)**で**Docusaurusをすぐに試す**こともできます。

### 必要なもの

- [Node.js](https://nodejs.org/en/download/)バージョン18.0以上:
  - Node.jsをインストールする際は、依存関係に関連するすべてのチェックボックスをチェックすることをおすすめします。

## 新しいサイトの生成

**クラシックテンプレート**を使用して新しいDocusaurusサイトを生成します。

次のコマンドを実行すると、クラシックテンプレートが自動的にプロジェクトに追加されます:

```bash
npm init docusaurus@latest my-website classic
```

このコマンドはコマンドプロンプト、Powershell、ターミナル、またはコードエディタの統合ターミナルなどで実行できます。

このコマンドは、Docusaurusを実行するために必要なすべての依存関係もインストールします。

## サイトの起動

開発サーバーを実行します:

```bash
cd my-website
npm run start
```

`cd`コマンドは作業するディレクトリを変更します。新しく作成したDocusaurusサイトを操作するには、ターミナルでそのディレクトリに移動する必要があります。

`npm run start`コマンドはウェブサイトをローカルでビルドし、開発サーバーを通じて提供します。http://localhost:3000/ で閲覧できるようになります。

`docs/intro.md`（このページ）を開いて数行編集してみましょう：サイトは**自動的に再読み込み**され、変更が表示されます。
